"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.interpretCardsProps = exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _lodash = require("lodash");
var _TableRow = _interopRequireDefault(require("@material-ui/core/TableRow"));
var _Attribute = _interopRequireDefault(require("../Attribute"));
var _ItemActions = _interopRequireDefault(require("../ItemActions"));
var _ItemHeader = _interopRequireDefault(require("../ItemHeader"));
var _withEditableTypography = _interopRequireDefault(require("../withEditableTypography"));
var _useStyle = _interopRequireDefault(require("../useStyle"));
var _helpers = require("../../helpers");
var _state = _interopRequireDefault(require("../state"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
//= ===============================================================================
// Helpers
//= ===============================================================================

const interpretCardsProps = (cardProps = {}, currentData = {}, {
  disableEditor = false,
  disableMultiselect = false,
  disableRemove = false
}) => {
  const getValue = (xs, defaultValue) => {
    const v = (0, _lodash.get)(cardProps, xs);
    if ((0, _lodash.isFunction)(v)) return v(currentData);
    if ((0, _lodash.isString)(v)) return (0, _lodash.get)(currentData, v);
    return !(0, _lodash.isNil)(v) ? v : defaultValue;
  };
  const negate = xs => !xs;
  return {
    ...cardProps,
    actions: (0, _lodash.get)(cardProps, 'actions', []),
    attributes: (0, _lodash.get)(cardProps, 'attributes', []),
    color: getValue('onColor', currentData),
    description: getValue('describe'),
    title: getValue('title'),
    showEditor: negate(getValue('disableEditor', disableEditor)),
    showMultiselect: negate(getValue('disableMultiselect', disableMultiselect)),
    showRemove: negate(getValue('disableRemove', disableRemove)),
    isIn: v => Object.entries((0, _lodash.get)(cardProps, 'editable', {})).filter(([key]) => key === v).reduce((obj, [key, value]) => Object.assign(obj, {
      name: key,
      ...value
    }), {})
  };
};

//= ===============================================================================
// Component
//= ===============================================================================
exports.interpretCardsProps = interpretCardsProps;
const Item = ({
  children,
  cardProps,
  // alias for cardProps
  rowResolver,
  renderMobileColumns,
  hasNested,
  toggleNested,
  nestedIsVisible,
  renderNestedTableRow,
  item,
  ctx,
  under,
  collectionName
}) => {
  const cls = (0, _useStyle.default)({
    id: item === null || item === void 0 ? void 0 : item.id,
    hasNested
  });
  const {
    actions,
    attributes,
    color,
    description,
    isIn,
    showEditor,
    showMultiselect,
    showRemove,
    title,
    icon,
    photo
  } = interpretCardsProps(rowResolver || cardProps, item, ctx);
  return /*#__PURE__*/_react.default.createElement(_TableRow.default, {
    className: cls.row
  }, /*#__PURE__*/_react.default.createElement(_ItemHeader.default, {
    renderMobileColumns: renderMobileColumns,
    showMultiselect: showMultiselect,
    item: item,
    color: color,
    description: description,
    isIn: isIn,
    title: title,
    photo: photo,
    icon: icon
  }), /*#__PURE__*/_react.default.createElement(_Attribute.default, {
    attributes: attributes,
    isIn: isIn,
    component: (0, _withEditableTypography.default)({
      data: item,
      collectionName,
      under
    })
  }), /*#__PURE__*/_react.default.createElement(_ItemActions.default, _extends({
    actions: actions,
    showEditor: showEditor,
    showRemove: showRemove,
    toggleNested: toggleNested,
    nestedIsVisible: nestedIsVisible,
    renderNestedTableRow: renderNestedTableRow
  }, item), children));
};
Item.propTypes = {
  children: _propTypes.default.node.isRequired,
  cardProps: _propTypes.default.shape({
    title: _propTypes.default.string,
    description: _propTypes.default.string
  }),
  rowResolver: _propTypes.default.shape({
    title: _propTypes.default.string,
    description: _propTypes.default.string
  }),
  item: _propTypes.default.shape({
    id: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]),
    color: _propTypes.default.string
  }).isRequired,
  renderMobileColumns: _propTypes.default.func,
  ..._helpers.override.propTypes
};
Item.defaultProps = {
  renderMobileColumns: null,
  ..._helpers.override.defaultProps
};
const BlockWastedRenders = /*#__PURE__*/_react.default.memo(Item, (prev, curr) => (0, _lodash.isEqual)(prev === null || prev === void 0 ? void 0 : prev.item, curr === null || curr === void 0 ? void 0 : curr.item) && (0, _lodash.isEqual)(prev === null || prev === void 0 ? void 0 : prev.ctx, curr === null || curr === void 0 ? void 0 : curr.ctx) && (prev === null || prev === void 0 ? void 0 : prev.nestedIsVisible) === (curr === null || curr === void 0 ? void 0 : curr.nestedIsVisible));
var _default = props => /*#__PURE__*/_react.default.createElement(BlockWastedRenders, _extends({}, props, {
  ctx: (0, _lodash.pick)(_react.default.useContext(_state.default), ['disableEditor', 'disableMultiselect', 'disableRemove'])
}));
exports.default = _default;