"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sort = exports.search = exports.reducer = exports.haveLength = exports.group = exports.genNewShape = exports.filter = exports.checkValues = void 0;
var _q3UiHelpers = require("q3-ui-helpers");
var _lodash = require("lodash");
const checkValues = (original, transformed) => original.length && (transformed.length || Object.keys(transformed).length);
exports.checkValues = checkValues;
const haveLength = (...args) => args.every(_q3UiHelpers.array.hasLength);
exports.haveLength = haveLength;
const testSearchTerm = val => item => !val.length || new RegExp(val, 'gi').test(JSON.stringify(item));
const search = searchTerm => xs => searchTerm ? xs.filter(testSearchTerm(searchTerm)) : xs;
exports.search = search;
const filter = obj => xs => {
  if (!_q3UiHelpers.array.hasLength(xs) || !obj || !obj.fn) return xs;
  return xs.filter(obj.fn);
};
exports.filter = filter;
const sort = obj => xs => {
  if (!_q3UiHelpers.array.hasLength(xs) || !obj) return xs;
  const {
    label,
    fn = null,
    direction = 'asc'
  } = obj;
  return (0, _lodash.orderBy)(xs, [(0, _lodash.isFunction)(fn) ? fn : label], [direction]);
};
exports.sort = sort;
const OTHER = 'other';
const genNewShape = groupBy => {
  const base = groupBy.reduce((acc, option) => {
    acc[option.label] = [];
    return acc;
  }, {});
  return {
    ...base,
    [OTHER]: []
  };
};
exports.genNewShape = genNewShape;
const group = groupBy => xs => {
  if (!_q3UiHelpers.array.hasLength(groupBy) || !_q3UiHelpers.array.hasLength(xs)) return xs;
  return xs.reduce((acc, x) => {
    // eslint-disable-next-line array-callback-return
    const wasTrue = groupBy.some(({
      label,
      fn
    }) => {
      if (fn(x)) {
        acc[label].push(x);
        return true;
      }
      return false;
    });
    if (!wasTrue) {
      acc[OTHER].push(x);
    }
    return acc;
  }, genNewShape(groupBy));
};
exports.group = group;
const reducer = (state, {
  type,
  payload
}) => {
  switch (type) {
    case 'filterBy':
      return {
        ...state,
        filterBy: payload
      };
    case 'sortBy':
      return {
        ...state,
        sortBy: payload
      };
    case 'input':
      return {
        ...state,
        input: payload
      };
    default:
      return state;
  }
};
exports.reducer = reducer;